attribute vec4 a_position;
attribute vec4 a_color;
attribute vec2 a_texCoord;
attribute vec4 a_startEnd;

uniform highp mat4 u_modelViewProjectionMatrix;
uniform vec4 u_materialAmbient;

uniform float u_time;

varying vec4 v_color;
varying vec2 v_texCoord;

#define M_HALF_PI 3.1415926535897932384626433832795/2.0

void main() {
	// Constants now, should be input-value (Uniform if possible)	
	float fadeEnd = 25.0 * 0.001;
	float fadeBegin = 10.0 * 0.001;
	
	// Transform from (0, 1) to (-1, 1)
	float showMin = a_startEnd.x * 2.0 - 1.0;
	float showMax = a_startEnd.y * 2.0 - 1.0;
	float maxMovement = a_startEnd.z * 2.0;
	float time = a_startEnd.w;
	
	// Starts at half pi because we want it to be at 0 the first few seconds and we add half the move distance to this value
	float movement = sin(time + M_HALF_PI) * maxMovement * 0.5 - maxMovement * 0.5;
	gl_Position = u_modelViewProjectionMatrix * a_position;
	gl_Position.x = gl_Position.x + movement;
	v_color = a_color * vec4(u_materialAmbient.a, u_materialAmbient.a, u_materialAmbient.a, 1.0);
	v_texCoord = a_texCoord;
	
	// Fade start and end
	// Local space works fine (Make sure the parameters are in local space)
	//v_color.a = smoothstep(showMin-fadeBegin, showMin, a_position.x) * 1.0-smoothstep(showMax, showMax+fadeEnd, a_position.x);
	
	// Screen-space
	v_color.a = smoothstep(showMin-fadeBegin, showMin, gl_Position.x) * 1.0-smoothstep(showMax, showMax+fadeEnd, gl_Position.x);
}